==> win32hooking-0.0.1.tar.gz: win32hooking-0.0.1/setup.py <==
from setuptools import setup, find_packages

setup(
    name='Win32Hooking',
    version="0.0.1",
    py_modules=['Win32Hooking'],
    packages=find_packages(include=[]),
    install_requires=[],
    scripts=[],
    author="Maurice Lambert",
    author_email="mauricelambert434@gmail.com",
    maintainer="Maurice Lambert",
    maintainer_email="mauricelambert434@gmail.com",
    description='This module hooks IAT and EAT to monitor all external functions calls, very useful for [malware] reverse and debugging.',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/mauricelambert/Win32Hooking",
    project_urls={
        "Github": "https://github.com/mauricelambert/Win32Hooking",
        "Documentation": "https://mauricelambert.github.io/info/python/security/Win32Hooking.html",
        "Python Executable": "https://mauricelambert.github.io/info/python/security/Win32Hooking.pyz",
        "Windows Executable": "https://mauricelambert.github.io/info/python/security/Win32Hooking.exe",
    },
    download_url="https://mauricelambert.github.io/info/python/security/Win32Hooking.pyz",
    include_package_data=True,
    classifiers=[
        "Topic :: System",
        "Topic :: Security",
        "Environment :: Console",
        "Topic :: System :: Shells",
        "Natural Language :: English",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        "Topic :: System :: System Shells",
        "Programming Language :: Python :: 3.8",
        'Operating System :: Microsoft :: Windows',
        "Topic :: System :: Systems Administration",
        "Intended Audience :: System Administrators",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
    ],
    keywords=['reverse', 'win32', 'winapi', 'hook', 'iat', 'eat', 'hooking', 'api-hooking', 'malware-reverse', 'hook-import', 'hook-export', 'debugging'],
    platforms=['Windows', 'Linux', "MacOS"],
    license="GPL-3.0 License",
    entry_points = {
        'console_scripts': [
            'Win32Hooking = Win32Hooking:main'
        ],
    },
    python_requires='>=3.8',
)

==> win32hooking-1.0.0.tar.gz: win32hooking-1.0.0/setup.py <==
from setuptools import setup, find_packages

setup(
    name='Win32Hooking',
    version="1.0.0",
    py_modules=['Win32Hooking'],
    packages=find_packages(include=[]),
    install_requires=["PyPeLoader>=0.2.0", "PythonToolsKit>=1.2.4"],
    scripts=[],
    author="Maurice Lambert",
    author_email="mauricelambert434@gmail.com",
    maintainer="Maurice Lambert",
    maintainer_email="mauricelambert434@gmail.com",
    description='This module hooks IAT and EAT to monitor all external functions calls, very useful for [malware] reverse and debugging.',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/mauricelambert/Win32Hooking",
    project_urls={
        "Github": "https://github.com/mauricelambert/Win32Hooking",
        "Documentation": "https://mauricelambert.github.io/info/python/security/Win32Hooking.html",
        "Python Executable": "https://mauricelambert.github.io/info/python/security/Win32Hooking.pyz",
        "Windows Executable": "https://mauricelambert.github.io/info/python/security/Win32Hooking.exe",
    },
    download_url="https://mauricelambert.github.io/info/python/security/Win32Hooking.pyz",
    include_package_data=True,
    classifiers=[
        "Topic :: System",
        "Topic :: Security",
        "Environment :: Console",
        "Topic :: System :: Shells",
        "Natural Language :: English",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        "Topic :: System :: System Shells",
        "Programming Language :: Python :: 3.8",
        'Operating System :: Microsoft :: Windows',
        "Topic :: System :: Systems Administration",
        "Intended Audience :: System Administrators",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
    ],
    keywords=['reverse', 'win32', 'winapi', 'hook', 'iat', 'eat', 'hooking', 'api-hooking', 'malware-reverse', 'hook-import', 'hook-export', 'debugging'],
    platforms=['Windows', 'Linux', "MacOS"],
    license="GPL-3.0 License",
    entry_points = {
        'console_scripts': [
            'Win32Hooking = Win32Hooking:main'
        ],
    },
    python_requires='>=3.8',
)
